--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

-----------------------------------------------------
-- Here are the default Advanced Movement Commands --
-----------------------------------------------------

-- These are here so you may view/add/remove/change advanced movement commands

function InitCustomAMCs()

	-- Check if we're using AMCs (and not quickdials)
	if EnableAMC and not QuickdialAMC then

		-- Add an attack function
		AMC_AddCommand("19", function(target)
			CMD_Attack( { SEQ_ATTACK, target } )
			return false
		end)

		-- Add a kite function
		AMC_AddCommand("17", function(target)
			-- Check if the target is our owner
			if target ~= OwnerID then
				-- Its not, so kite it
				CMD_Kite( { SEQ_KITE, target } )
			else
				--[[
					Its our owner, so change passive mode to
					an aggro that will only defend or aggro kite
					monsters.
				--]]
				if HomunAcquireOverride == AI_AggroKitesOnly then
					-- Turn it off
					HomunAcquireOverride = nil
				else
					-- Turn it on
					HomunAcquireOverride = AI_AggroKitesOnly
				end
			end

			return false
		end)

		-- Add a mode-changing function
		AMC_AddParser("2", function(target,command)
			-- Default to moving
			local ret = true

			-- Change modes depending on the command
			if command == "4" then
				Mode = MODE_PASSIVE
				Log(0,"Mode changed to: Passive")
				ret = false
			elseif command == "6" then
				Mode = MODE_AGGRO
				Log(0,"Mode changed to: Aggressive")
				ret = false
			end

			-- Have the personality acknowledge the command
			Personality_Yes(target)
			
			-- Don't follow with the move command if we actually
			-- did something
			return ret
		end)

		-- Add a function to deal with friend commands
		AMC_AddParser("4", function(target,command)
			-- Default to following the move command
			local ret = true

			-- Decide what the subcommand wants us to do
			if command == "4" then
				-- Load the list
				LoadFriends()

				-- Have the personality acknowledge the command
				Personality_Yes(target)

				-- Don't follow the move command
				ret = false

			elseif command == "6" then
				-- Save the list
				SaveFriends()

				-- Have the personality acknowledge the command
				Personality_Yes(target)

				-- Don't follow the move command
				ret = false
			
			elseif command == "8" then
				-- Add the friend
				AddFriend(target)

				-- Have the personality acknowledge the command
				Personality_Other(target,PersoActions.heart)

				-- Don't follow the move command
				ret = false

			elseif command == "2" then
				-- Delete the friend
				DelFriend(target)

				-- Have the personality acknowledge the command
				Personality_No(target)

				-- Don't follow the move command
				ret = false
			end

			-- Don't follow the move if our subcommand was valid
			return ret
		end)


	-- Alternatively, check if we're using quickdial AMCs
	elseif EnableAMC and QuickdialAMC then

		-- Add an attack function to quickdial "9"
		AMC_AddCommand("9", function(target)
			-- Command the attack
			CMD_Attack( { SEQ_ATTACK, target } )

			-- False means: Do not move to the button
			return false
		end)

		-- Add a kite function to quickdial "7"
		AMC_AddCommand("7", function(target)
			-- Check if the target is our owner
			if target ~= OwnerID then
				-- Command the kite
				CMD_Kite( { SEQ_KITE, target } )
			else
				--[[
					Its our owner, so change passive mode to
					an aggro that will only defend or aggro kite
					monsters.
				--]]
				if HomunAcquireOverride == AI_AggroKitesOnly then
					-- Turn it off
					HomunAcquireOverride = nil
				else
					-- Turn it on
					HomunAcquireOverride = AI_AggroKitesOnly
				end
			end


			-- False so they don't move to the button
			return false
		end)

		-- Add a friend add/remove/save button
		AMC_AddCommand("4", function(target)
			-- Check if we're clicking on our own "2" button
			if target == OwnerID then
				-- Save the friend list
				SaveFriends()

				-- Have the personality acknowledge the command
				Personality_Yes(target)

				-- Since we did it, don't do the move
				return false
			else
				-- Clicked someone/something else, check if its a monster
				-- in a Player-vs-Monster only environment
				if not PVPZone and IsMonster(target) == 1 then
					-- Its not a valid friend, so move to
					-- the ground-location
					return true
				end

				-- Check if they are a permanent friend
				if IsPermFriend(target) then
					-- Have the personality acknowledge the command
					Personality_No(target)

					-- Remove them
					DelFriend(target)
				else
					-- Have the personality acknowledge the command
					Personality_Other(target,PersoActions.heart)

					-- Add them
					AddFriend(target)
				end

				-- Since we did it (or not), don't do the move
				return false
			end
		end)

	end
end
