--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

-------------------------------
-- Monster-Specific Settings --
-------------------------------

-- This line indicates the table of monsters will be held in a variable named...
MonsterDB = {

--[[ Monster entries take the form of:

{ ID, prio, atk?, skLvl, skDly, skMax, aSKLv, aSkDl, aSkMx, defOnly, kite, ffa },

	- "ID" is the monster's type, which can be found from RO Empire's
		monster database (listed as MID, in parenthesis after the
		monster's name). Other databases may show this value as well.

	- "prio" is a value to prioritize killing of monsters.

		Clarification: If a "Steel Chonchon" has a priority of 5 and
			a "Zenorc" has a priority of 3, the homunculus will
			attack the steel chonchon before the zenorc.

	- "atk?" is a boolean (aka true/false) that determines whether or
		not the homunculus should attack the monster with physical attacks

	- "skLvl" is the highest level of an attack skill that is allowed to be
		used against the monster (0 to disable homunculus skills against it)

		NOTE: Disabling "AllowSkills" in Config.lua will disable *ALL*
			homunculus skill usage, regardless of monster-specific settings.

	- "skDly" is the minimum amount of time (in milliseconds) that should be
		waited in between uses of a homunculus skill against this monster.

	- "skMax" is the maximum number of times to cast a homunculi's skills against
		the monster (-1 for infinite)

	- "aSkLv" is the highest level of an auto-sword bolt to be cast against the monster
		(0 to disable alchemist skills against the monster)

	- "aSkDl" is the minimum amount of time (in milliseconds) that should be
		waited in between uses of a auto-sword bolt against this monster

	- "aSkMx" is the maximum number of times to cast auto-sword bolts against
		the monster (-1 for infinite)

	- "defOnly" is a boolean (true/false) to decide whether or not the monster
		should be attacked ONLY if it attacks you first

	- "kite" is a boolean (true/false) that will decide if the monster should be
		kite-tanked or attacked with the intention of killing.

			NOTE: Kiting is experimental and should be used with care.

			NOTE: When defending against monsters that are supposed to
				be kited, they will be the last to get targetted.
				(regular killing is usually faster and faster
				defense is important)

	- "ffa" is a boolean (true/false) to determine whether or not a monster is
		considered "free-for-all", and can be "kill-stealed" at any time.
		This is intended for use with MVPs.


	NOTE: Setting any option to "nil" will use the default.	This is also true for
		leaving the option off completely (if its after all the options you
		set for the monster)

	NOTE: This table is optimized when the script is initialized.



For easier reference:
{ ID, prio, atk?, skLvl, skDly, skMax, aSKLv, aSkDl, aSkMx, defOnly, kite, ffa },

--]]


--=== Example ===--
--[[ This example will prioritize killing of plants below every other monster, but
	will not allow the homunculus to use skills against the plants. It will also
	not allow sword bolts to be casted against plants
--]]
{ 1078, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Red Plant
{ 1079, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Blue Plant
{ 1080, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Green Plant
{ 1081, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Yellow Plant
{ 1082, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- White Plant
{ 1083, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Shining Plant
{ 1084, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Red Mushroom
{ 1085, 0, true, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Black Mushroom

-- These next ones will prevent the homunculus from attacking summoned plants
{ 1555, nil, false, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Summoned Parasite
{ 1575, nil, false, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Summoned Flora
{ 1579, nil, false, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Summoned Hydra
{ 1589, nil, false, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Summoned Mandragora
{ 1590, nil, false, 0, nil, nil, 0, nil, nil, nil, nil, nil },		-- Summoned Geographer


-- Put your own monsters here



-- End of the monster table
}

------------------------
-- Supporting Options --
------------------------

--[[ This is the default monster entry

	We want default priority to be 1, allow melee attacks, allow
	skills to be used up to level 5, wait 0.5 seconds between casting
	of attack skills, cast only one homunculus skill,
	cast level 3 sword bolts, wait 3 seconds between casting of
	sword bolts, and cast sword bolts as many times as needed.

	NOTE: ID has no effect on this, but is left in so as to conform to
		the above descriptions.
--]]
DefaultMonsterSettings = { nil, 1, true, 5, 500, 1, 3, 3000, -1, false, false, false }
