--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]


--[[

	****** READ ******
	
	You do not need to edit this file. If you wish to
	change the way your homunculus behaves, please edit
	Conf\Config.lua.
	
	This file checks to make sure you will not get any
	Lua errors in the event that your Config.lua has invalid
	values in it.
	
--]]


--------------------------------
-- Configuration Verification --
--------------------------------

-- Function to verify that all of the configuration options exist
-- (partly so users aren't forced to update their Config.lua constantly)
function CheckConfig()
	-- Keep a log of invalids, and out-of-ranges
	local invalids = ""
	local oorange = ""

	-- Verify AlchemistDex
	if type(AlchemistDex) ~= "number" then
		invalids = invalids .. " AlchemistDex"
		AlchemistDex = 30
	else
		if AlchemistDex < 1 then
			oorange = oorange .. " AlchemistDex"
			AlchemistDex = 1
		elseif AlchemistDex > 150 then
			oorange = oorange .. " AlchemistDex"
			AlchemistDex = 150
		end
	end

	-- Verify AlchemistPhen
	if type(AlchemistPhen) ~= "boolean" then
		invalids = invalids .. " AlchemistPhen"
		AlchemistPhen = false
	end

	-- Verify the SightRange variable
	if type(SightRange) ~= "number" then
		invalids = invalids .. " SightRange"
		SightRange = 12
	else
		-- Check the range of the number
		if SightRange > 15 then
			oorange = oorange .. " SightRange"
			SightRange = 15
		elseif SightRange < 2 then
			oorange = oorange .. " SightRange"
			SightRange = 2
		end
	end
	
	-- Verify the MaxHomunRange
	if type(MaxHomunRange) ~= "number" then
		invalids = invalids .. " MaxHomunRange"
		MaxHomunRange = 12
	else
		if MaxHomunRange > 15 then
			oorange = oorange .. " MaxHomunRange"
			MaxHomunRange = 15
		elseif MaxHomunRange < 2 then
			oorange = oorange .. " MaxHomunRange"
			MaxHomunRange = 2
		end
	end
	
	-- Verify HomunRangeChange
	if type(HomunRangeChange) ~= "number" then
		invalids = invalids .. " HomunRangeChange"
		HomunRangeChange = 4
	else
		-- Verify the range of HomunRangeChange
		if HomunRangeChange >= MaxHomunRange - 2 then
			oorange = oorange .. " HomunRangeChange"
			HomunRangeChange = MaxHomunRange - 2
		elseif HomunRangeChange < 0 then
			oorange = oorange .. " HomunRangeChange"
			HomunRangeChange = 0
		end
	end
	
	-- Verify HomunFollowDistance
	if type(HomunFollowDistance) ~= "number" then
		invalids = invalids .. " HomunFollowDistance"
		HomunFollowdistance = 3
	else
		-- Verify the range of HomunFollowDistance
		if HomunFollowDistance > MaxHomunRange - HomunRangeChange then
			oorange = oorange .. " HomunFollowDistance"
			HomunFollowDistance = MaxHomunRange - HomunRangeChange - 1
		elseif HomunFollowDistance < 1 then
			oorange = oorange .. " HomunFollowDistance"
			HomunFollowDistance = 1
		end
	end

	-- Verify HomunRunAhead
	if type(HomunRunAhead) ~= "boolean" then
		invalids = invalids .. " HomunRunAhead"
		HomunRunAhead = false
	end

	-- Verify AllowIgnoreOwner
	if type(AllowIgnoreOwner) ~= "boolean" then
		invalids = invalids .. " AllowIgnoreOwner"
		AllowIgnoreOwner = true
	end

	-- Verify EnableIdleMove
	if type(EnableIdleMove) ~= "boolean" then
		invalids = invalids .. " EnableIdleMove"
		EnableIdleMove = true
	end

	-- Verify TimeBeforeIdle
	if type(TimeBeforeIdle) ~= "number" then
		invalids = invalids .. " TimeBeforeIdle"
		TimeBeforeIdle = 1000
	else
		-- Check the bottom limit
		if TimeBeforeIdle < 0 then
			oorange = oorange .. " TimeBeforeIdle"
			TimeBeforeIdle = 0
		end
	end

	--[[
		=== Interjected PercentHP and PercentSP Verification
		=== Here, For Immediate Use
	--]]
	
	-- Verify PercentHP
	if type(PercentHP) ~= "boolean" then
		invalids = invalids .. " PercentHP"
		PercentHP = true
	end
	
	-- Verify PercentSP
	if type(PercentSP) ~= "boolean" then
		invalids = invalids .. " PercentSP"
		PercentSP = false
	end
	
	--[[
		=== Back to Following Config.lua Order
	--]]
	
	-- Verify IdleMoveHP
	if type(IdleMoveHP) ~= "number" then
		invalids = invalids .. " IdleMoveHP"
		IdleMoveHP = 50
	else
		-- Check the range
		if IdleMoveHP < 0 then
			oorange = oorange .. " IdleMoveHP"
			IdleMoveHP = 0
		elseif IdleMoveHP > 100 and PercentHP then
			oorange = oorange .. " IdleMoveHP"
			IdleMoveHP = 100
		end
	end

	-- Verify IdleMoveSP
	if type(IdleMoveSP) ~= "number" then
		invalids = invalids .. " IdleMoveSP"
		IdleMoveSP = 50
	else
		-- Check the range
		if IdleMoveSP < 0 then
			oorange = oorange .. " IdleMoveSP"
			IdleMoveSP = 0
		elseif IdleMoveSP > 100 and PercentSP then
			oorange = oorange .. " IdleMoveSP"
			IdleMoveSP = 100
		end
	end

	-- Verify EnableAMC
	if type(EnableAMC) ~= "boolean" then
		invalids = invalids .. " EnableAMC"
		EnableAMC = true
	end
	
	-- Verify QuickdialAMC
	if type(QuickdialAMC) ~= "boolean" then
		invalids = invalids .. " QuickdialAMC"
		QuickdialAMC = true
	end
	
	-- Verify AMCResetTime
	if type(AMCResetTime) ~= "number" then
		invalids = invalids .. " AMCResetTime"
		AMCResetTime = 5000
	else
		-- Verify the bottom limit of AMCResetTime
		if AMCResetTime < 100 then
			AMCResetTime = 100
		end
	end
	
	-- Verify DefaultAggro
	if type(DefaultAggro) ~= "boolean" then
		invalids = invalids .. " DefaultAggro"
		DefaultAggro = false
	end
	
	-- Verify AssistOwner
	if type(AssistOwner) ~= "boolean" then
		invalids = invalids .. " AssistOwner"
		AssistOwner = true
	end
	
	-- Verify AllowKS
	if type(AllowKS) ~= "boolean" then
		invalids = invalids .. " AllowKS"
		AllowKS = false
	end

	-- Verify ActorIgnoreTime
	if type(ActorIgnoreTime) ~= "number" then
		invalids = invalids .. " ActorIgnoreTime"
		ActorIgnoreTime = 5000
	else
		-- Verify the bottom limit
		if ActorIgnoreTime < 0 then
			ActorIgnoreTime = 0
		end
	end

	-- Verify EnableIgnoreAfterTicks
	if type(EnableIgnoreAfterTicks) ~= "boolean" then
		invalids = invalids .. " EnableIgnoreAfterTicks"
		EnableIgnoreAfterTicks = false
	end

	-- Verify ActorIgnoreAfterTicks
	if type(ActorIgnoreAfterTicks) ~= "number" then
		invalids = invalids .. " ActorIgnoreAfterTicks"
		ActorIgnoreAfterTicks = 30000
	else
		-- Check the bottom limit
		if ActorIgnoreAfterTicks < 5000 then
			oorange = oorange .. " ActorIgnoreAfterTicks"
			ActorIgnoreAfterTicks = 5000
		end
	end
	
	-- Verify AcquireTargetTimeout
	if type(AcquireTargetTimeout) ~= "number" then
		invalids = invalids .. " AcquireTargetTimeout"
		AcquireTargetTimeout = 50
	else
		-- Verify the bottom limit
		if AcquireTargetTimeout < 50 then
			AcquireTargetTimeout = 50
		end
	end
	
	-- Verify AcquireWhileLocked
	if type(AcquireWhileLocked) ~= "boolean" then
		invalids = invalids .. " AcquireWhileLocked"
		AcquireWhileLocked = false
	end

	-- Verify EnableAttacksTimeout
	if type(EnableAttacksTimeout) ~= "boolean" then
		invalids = invalids .. " EnableAttacksTimeout"
		EnableAttacksTimeout = false
	end

	-- Verify AttacksTimeout
	if type(AttacksTimeout) ~= "number" then
		invalids = invalids .. " AttacksTimeout"
		AttacksTimeout = 750
	else
		if AttacksTimeout < 250 then
			oorange = oorange .. " AttacksTimeout"
			AttacksTimeout = 250
		end
	end

	-- Verify AttacksMaxTries
	if type(AttacksMaxTries) ~= "number" then
		invalids = invalids .. " AttacksMaxTries"
		AttacksMaxTries = 3
	else
		if AttacksMaxTries < 1 then
			oorange = oorange .. " AttacksMaxTries"
			AttacksMaxTries = 1
		end
	end

	-- Verify KiteDefaultDistance
	if type(KiteDefaultDistance) ~= "number" then
		invalids = invalids .. " KiteDefaultDistance"
		KiteDefaultDistance = 6
	else
		-- Check the range
		if KiteDefaultDistance < 2 then
			oorange = oorange .. " KiteDefaultDistance"
			KiteDefaultDistance = 2
		elseif KiteDefaultDistance > MaxHomunRange - 4 then
			oorange = oorange .. " KiteDefaultDistance"
			KiteDefaultDistance = MaxHomunRange - 4
		end
	end

	-- Verify PassiveDefense
	if type(PassiveDefense) ~= "boolean" then
		invalids = invalids .. " PassiveDefense"
		PassiveDefense = true
	end
	
	-- Verify PassiveSkills
	if type(PassiveSkills) ~= "boolean" then
		invalids = invalids .. " PassiveSkills"
		PassiveSkills = true
	end
	
	-- Verify PrioritizeOwnerDefense (range verified during init)
	if type(PrioritizeOwnerDefense) ~= "number" then
		invalids = invalids .. " PrioritizeOwnerDefense"
		PrioritizeOwnerDefense = 1
	end
	
	-- Verify PrioritizeHomunDefense (range verified during init)
	if type(PrioritizeHomunDefense) ~= "number" then
		invalids = invalids .. " PrioritizeHomunDefense"
		PrioritizeHomunDefense = 5
	end

	-- Verify PrioritizeFriendDefense (range verified during init)
	if type(PrioritizeFriendDefense) ~= "number" then
		invalids = invalids .. " PrioritizeFriendDefense"
		PrioritizeFriendDefense = 4
	end

	-- Verify DefendFriends
	if type(DefendFriends) ~= "boolean" then
		invalids = invalids .. " DefendFriends"
		DefendFriends = true
	end

	-- Verify TemporaryFriendTiles
	if type(TemporaryFriendTiles) ~= "number" then
		invalids = invalids .. " TemporaryFriendTiles"
		TemporaryFriendTiles = -1
	end

	-- Verify AutoSaveFriends
	if type(AutoSaveFriends) ~= "boolean" then
		invalids = invalids .. " AutoSaveFriends"
		AutoSaveFriends = false
	end
	
	-- Verify AllowSkills
	if type(AllowSkills) ~= "boolean" then
		invalids = invalids .. " AllowSkills"
		AllowSkills = true
	end
	
	-- Verify SkillsCauseAttack
	if type(SkillsCauseAttack) ~= "boolean" then
		invalids = invalids .. " SkillsCauseAttack"
		SkillsCauseAttack = false
	end
	
	-- Verify MinSP
	if type(MinSP) ~= "number" then
		invalids = invalids .. " MinSP"
		MinSP = 0
	else
		-- Verify the range of MinSP
		if MinSP < 0 then
			MinSP = 0
		elseif MinSP > 100 and PercentSP then
			MinSP = 100
		end
	end

	-- Verify IgnoreAttackSkillRange
	if type(IgnoreAttackSkillRange) ~= "boolean" then
		invalids = invalids .. " IgnoreAttackSkillRange"
		IgnoreAttackSkillRange = false
	end

	-- Verify IgnoredRangeFromOwner
	if type(IgnoredRangeFromOwner) ~= "number" then
		invalids = invalids .. " IgnoredRangeFromOwner"
		IgnoredRangeFromOwner = 12
	end
	
	-- Verify MinAttackSkillLevel
	if type(MinAttackSkillLevel) ~= "number" then
		invalids = invalids .. " MinAttackSkillLevel"
		MinAttackSkillLevel = 1
	else
		-- Verify the range
		if MinAttackSkillLevel < 1 then
			oorange = oorange .. " MinAttackSkillLevel"
			MinAttackSkillLevel = 1
		elseif MinAttackSkillLevel > 5 then
			oorange = oorange .. " MinAttackSkillLevel"
			MinAttackSkillLevel = 5
		end
	end
	
	-- Verify MeleeSkills
	if type(MeleeSkills) ~= "boolean" then
		invalids = invalids .. " MeleeSkills"
		MeleeSkills = true
	end
	
	-- Verify ChaseSkills
	if type(ChaseSkills) ~= "boolean" then
		invalids = invalids .. " ChaseSkills"
		ChaseSkills = true
	end

	-- Verify LockOnAttackSkills
	if type(LockOnAttackSkills) ~= "boolean" then
		invalids = invalids .. " LockOnAttackSkills"
		LockOnAttackSkills = false
	end
	
	-- Verify SupportSkills
	if type(SupportSkills) ~= "boolean" then
		invalids = invalids .. " SupportSkills"
		SupportSkills = true
	end
	
	-- Verify HealSkills
	if type(HealSkills) ~= "boolean" then
		invalids = invalids .. " HealSkills"
		HealSkills = false
	end

	-- Verify AutoBoltSword
	if type(AutoBoltSword) ~= "boolean" then
		invalids = invalids .. " AutoBoltSword"
		AutoBoltSword = false
	end

	-- Verify AutoBoltMinLevel
	if type(AutoBoltMinLevel) ~= "number" then
		invalids = invalids .. " AutoBoltMinLevel"
		AutoBoltMinLevel = 1
	else
		-- Check the range
		if AutoBoltMinLevel < 1 then
			oorange = oorange .. " AutoBoltMinLevel"
			AutoBoltMinLevel = 1
		elseif AutoBoltMinLevel > 3 then
			oorange = oorange .. " AutoBoltMinLevel"
			AutoBoltMinLevel = 3
		end
	end

	-- Verify AutoBoltDelay
	if type(AutoBoltDelay) ~= "number" then
		invalids = invalids .. " AutoBoltDelay"
		AutoBoltDelay = 200
	else
		-- Check the bottom limit
		if AutoBoltDelay < 0 then
			oorange = oorange .. " AutoBoltDelay"
			AutoBoltDelay = 0
		end
	end

	-- Verify AutoAidPot
	if type(AutoAidPot) ~= "boolean" then
		invalids = invalids .. " AutoAidPot"
		AutoAidPot = false
	end
	
	-- Verify AidPotHP
	if type(AidPotHP) ~= "number" then
		invalids = invalids .. " AidPotHP"
		AidPotHP = 25
	else
		-- Verify the range of AidPotHP
		if AidPotHP < 0 then
			oorange = oorange .. " AidPotHP"
			AidPotHP = 0
		elseif AidPotHP > 100 and PercentHP then
			oorange = oorange .. " AidPotHP"
			AidPotHP = 100
		end
	end
	
	-- Verify AidPotLowest
	if type(AidPotLowest) ~= "number" then
		invalids = invalids .. " AidPotLowest"
		AidPotLowest = 3
	else
		-- Verify the range of AidPotLowest
		if AidPotLowest < 1 then
			oorange = oorange .. " AidPotLowest"
			AidPotLowest = 1
		elseif AidPotLowest > 4 then
			oorange = oorange .. " AidPotLowest"
			AidPotLowest = 4
		end
	end
	
	-- Verify AidPotHighest
	if type(AidPotHighest) ~= "number" then
		invalids = invalids .. " AidPotHighest"
		AidPotHighest = 4
	else
		-- Verify the range
		if AidPotHighest < 1 then
			oorange = oorange .. " AidPotHighest"
			AidPotHighest = 1
		elseif AidPotHighest > 4 then
			oorange = oorange .. " AidPotHighest"
			AidPotHighest = 4
		end
	end

	-- Verify AidPotWaitAfterMove
	if type(AidPotWaitAfterMove) ~= "number" then
		invalids = invalids .. " AidPotWaitAfterMove"
		AidPotWaitAfterMove = 500
	else
		-- Verify the bottom limit
		if AidPotWaitAfterMove < 0 then
			oorange = oorange .. " AidPotWaitAfterMove"
			AidPotWaitAfterMove = 0
		end
	end

	-- Verify AidPotMoveCloser
	if type(AidPotMoveCloser) ~= "boolean" then
		invalids = invalids .. " AidPotMoveCloser"
		AidPotMoveCloser = true
	end
	
	-- Verify AidPotIncrement
	if type(AidPotIncrement) ~= "number" then
		invalids = invalids .. " AidPotIncrement"
		AidPotIncrement = 3
	else
		-- Verify the bottom limit
		if AidPotIncrement < 0 then
			AidPotIncrement = 0
		end
	end
	
	-- Verify AidPotTriesPerLevel
	if type(AidPotTriesPerLevel) ~= "number" then
		invalids = invalids .. " AidPotTriesPerLevel"
		AidPotTriesPerLevel = 3
	else
		-- Verify the bottom limit
		if AidPotTriesPerLevel < 1 then
			AidPotTriesPerLevel = 1
		end
	end
	
	-- Verify AidPotTriesReset
	if type(AidPotTriesReset) ~= "number" then
		invalids = invalids .. " AidPotTriesReset"
		AidPotTriesReset = 60000
	else
		-- Verify the bottom limit
		if AidPotTriesReset < 50 then
			AidPotTriesReset = 50
		end
	end
	
	-- Verify AidPotWaitTime
	if type(AidPotWaitTime) ~= "number" then
		invalids = invalids .. " AidPotWaitTime"
		AidPotWaitTime = 200
	else
		-- Verify the bottom limit
		if AidPotWaitTime < 50 then
			AidPotWaitTime = 50
		end
	end

	-- Verify AutoRes
	if type(AutoRes) ~= "boolean" then
		invalids = invalids .. " AutoRes"
		AutoRes = false
	end

	-- Verify AutoResHP
	if type(AutoResHP) ~= "number" then
		invalids = invalids .. " AutoResHP"
		AutoResHP = 15
	else
		-- Verify the range of AutoResHP
		if AutoResHP < 0 then
			oorange = oorange .. " AutoResHP"
			AutoResHP = 0
		elseif AutoResHP > 100 and PercentHP then
			oorange = oorange .. " AutoResHP"
			AutoResHP = 100
		end
	end

	-- Verify AutoResSmart
	if type(AutoResSmart) ~= "boolean" then
		invalids = invalids .. " AutoResSmart"
		AutoResSmart = true
	end

	-- Verify AutoResDelay
	if type(AutoResDelay) ~= "number" then
		invalids = invalids .. " AutoResDelay"
		AutoResDelay = 400
	else
		-- Check the bottom limit
		if AutoResDelay < 0 then
			oorange = oorange .. " AutoResDelay"
			AutoResDelay = 0
		end
	end
	
	-- Verify AmistrBulwarkOwner
	if type(AmistrBulwarkOwner) ~= "number" then
		invalids = invalids .. " AmistrBulwarkOwner"
		AmistrBulwarkOwner = 3
	else
		-- Verify the bottom limit
		if AmistrBulwarkOwner < 0 then
			AmistrBulwarkOwner = 0
		end
	end
	
	-- Verify AmistrBulwarkHomun
	if type(AmistrBulwarkHomun) ~= "number" then
		invalids = invalids .. " AmistrBulwarkHomun"
		AmistrBulwarkHomun = 6
	else
		-- Verify the bottom limit
		if AmistrBulwarkHomun < 0 then
			AmistrBulwarkHomun = 0
		end
	end
	
	-- Verify AmistrBulwarkMinLevel
	if type(AmistrBulwarkMinLevel) ~= "number" then
		invalids = invalids .. " AmistrBulwarkMinLevel"
		AmistrBulwarkMinLevel = 1
	else
		-- Verify the range
		if AmistrBulwarkMinLevel < 1 then
			oorange = oorange .. " AmistrBulwarkMinLevel"
			AmistrBulwarkMinLevel = 1
		elseif AmistrBulwarkMinLevel > 5 then
			oorange = oorange .. " AmistrBulwarkMinLevel"
			AmistrBulwarkMinLevel = 5
		end
	end
	
	-- Verify CastlingAttackers
	if type(CastlingAttackers) ~= "number" then
		invalids = invalids .. " CastlingAttackers"
		CastlingAttackers = 5
	else
		-- Check the bottom limit
		if CastlingAttackers < 0 then
			oorange = oorange .. " CastlingAttackers"
			CastlingAttackers = 0
		end
	end
	
	-- Verify CastlingHP
	if type(CastlingHP) ~= "number" then
		invalids = invalids .. " CastlingHP"
		CastlingHP = 100
	else
		-- Check the range
		if CastlingHP < 0 then
			oorange = oorange .. " CastlingHP"
			CastlingHP = 0
		elseif CastlingHP > 100 and PercentHP then
			oorange = oorange .. " CastlingHP"
			CastlingHP = 100
		end
	end

	-- Verify CastlingDelay
	if type(CastlingDelay) ~= "number" then
		invalids = invalids .. " CastlingDelay"
		CastlingDelay = 500
	else
		-- Check the range
		if CastlingDelay < 0 then
			oorange = oorange .. " CastlingDelay"
			CastlingDelay = 0
		end
	end

	-- Verify FilirUseDuration
	if type(FilirUseDuration) ~= "boolean" then
		invalids = invalids .. " FilirUseDuration"
		FilirUseDuration = true
	end

	-- Verify FlittingLevel
	if type(FlittingLevel) ~= "number" then
		invalids = invalids .. " FlittingLevel"
		FlittingLevel = 5
	else
		-- Check the range
		if FlittingLevel < 0 then
			oorange = oorange .. " FlittingLevel"
			FlittingLevel = 0
		elseif FlittingLevel > 5 then
			oorange = oorange .. " FlittingLevel"
			FlittingLevel = 5
		end
	end

	-- Verify FlittingMinTicks
	if type(FlittingMinTicks) ~= "number" then
		invalids = invalids .. " FlittingMinTicks"
		FlittingMinTicks = 0
	end

	-- Verify FlittingSPSaveTicks
	if type(FlittingSPSaveTicks) ~= "number" then
		invalids = invalids .. " FlittingSPSaveTicks"
		FlittingSPSaveTicks = 20000
	else
		-- Check the bottom
		if FlittingSPSaveTicks < 0 then
			oorange = oorange .. " FlittingSPSaveTicks"
			FlittingSPSaveTicks = 0
		end
	end

	-- Verify MinHealingHands
	if type(MinHealingHands) ~= "number" then
		invalids = invalids .. " MinHealingHands"
		MinHealingHands = 1
	else
		-- Change range
		if MinHealingHands < 1 then
			oorange = oorange .. " MinHealingHands"
			MinHealingHands = 1
		elseif MinHealingHands > 5 then
			oorange = oorange .. " MinHealingHands"
			MinHealingHands = 5
		end
	end

	-- Verify HealingHandsHP
	if type(HealingHandsHP) ~= "number" then
		invalids = invalids .. " HealingHandsHP"
		HealingHandsHP = 50
	else
		-- Check the range
		if HealingHandsHP < 0 then
			oorange = oorange .. " HealingHandsHP"
			HealingHandsHP = 0
		elseif HealingHandsHP > 100 and PercentHP then
			oorange = oorange .. " HealingHandsHP"
			HealingHandsHP = 100
		end
	end

	-- Verify ChaoticBlessingsOwnerHP
	if type(ChaoticBlessingsOwnerHP) ~= "number" then
		invalids = invalids .. " ChaoticBlessingsOwnerHP"
		ChaoticBlessingsOwnerHP = 50
	else
		-- Check the range
		if ChaoticBlessingsOwnerHP < 0 then
			oorange = oorange .. " ChaoticBlessingsOwnerHP"
			ChaoticBlessingsOwnerHP = 0
		elseif ChaoticBlessingsOwnerHP > 100 and PercentHP then
			oorange = oorange .. " ChaoticBlessingsOwnerHP"
			ChaoticBlessingsOwnerHP = 100
		end
	end

	-- Verify ChaoticBlessingsHomunHP
	if type(ChaoticBlessingsHomunHP) ~= "number" then
		invalids = invalids .. " ChaoticBlessingsHomunHP"
		ChaoticBlessingsHomunHP = 0
	else
		-- Check the range
		if ChaoticBlessingsHomunHP < 0 then
			oorange = oorange .. " ChaoticBlessingsHomunHP"
			ChaoticBlessingsHomunHP = 0
		elseif ChaoticBlessingsHomunHP > 100 and PercentHP then
			oorange = oorange .. " ChaoticBlessingsHomunHP"
			ChaoticBlessingsHomunHP = 100
		end
	end

	-- Verify MaxChaoticBlessings
	if type(MaxChaoticBlessings) ~= "number" then
		invalids = invalids .. " MaxChaoticBlessings"
		MaxChaoticBlessings = 1
	else
		-- Check the range
		if MaxChaoticBlessings < 1 then
			oorange = oorange .. " MaxChaoticBlessings"
			MaxChaoticBlessings = 1
		elseif MaxChaoticBlessings > 5 then
			oorange = oorange .. " MaxChaoticBlessings"
			MaxChaoticBlessings = 5
		end
	end

	-- Verify AntiPosLag
	if type(AntiPosLag) ~= "boolean" then
		invalids = invalids .. " AntiPosLag"
		AntiPosLag = true
	end

	-- Verify PosLagTries
	if type(PosLagTries) ~= "number" then
		invalids = invalids .. " PosLagTries"
		PosLagTries = 3
	else
		-- Check the bottom limit
		if PosLagTries < 1 then
			oorange = oorange .. " PosLagTries"
			PosLagTries = 1
		end
	end

	-- Verify PosLagDelay
	if type(PosLagDelay) ~= "number" then
		invalids = invalids .. " PosLagDelay"
		PosLagDelay = 500
	else
		-- Check the bottom limit
		if PosLagDelay < 0 then
			oorange = oorange .. " PosLagDelay"
			PosLagDelay = 50
		end
	end

	-- Verify OwnerMinSP
	if type(OwnerMinSP) ~= "number" then
		invalids = invalids .. " OwnerMinSP"
		OwnerMinSP = 0
	else
		-- Check the range on it
		if OwnerMinSP < 0 then
			oorange = oorange .. " OwnerMinSP"
			OwnerMinSP = 0
		elseif OwnerMinSP > 100 and PercentSP then
			oorange = oorange .. " OwnerMinSP"
			OwnerMinSP = 100
		end
	end

	--[[
	
		NOTE: PercentHP and PercentSP moved farther up
	
	--]]

	-- Verify AIStartWait
	if type(AIStartWait) ~= "number" then
		invalids = invalids .. " AIStartWait"
		AIStartWait = 1000
	else
		-- Check the bottom limit of it
		if AIStartWait < 0 then
			oorange = oorange .. " AIStartWait"
			AIStartWait = 0
		end
	end

	-- Verify AssumePVP
	if type(AssumePVP) ~= "boolean" then
		invalids = invalids .. " AssumePVP"
		AssumePVP = false
	end

	-- Verify AssumeWoE
	if type(AssumeWoE) ~= "boolean" then
		invalids = invalids .. " AssumeWoE"
		AssumeWoE = false
	end

	-- Verify CheckPVP
	if type(CheckPVP) ~= "boolean" then
		invalids = invalids .. " CheckPVP"
		CheckPVP = true
	end
	
	-- Verify MoveIsAttackWhenDistance
	if type(MoveIsAttackWhenDistance) ~= "number" then
		invalids = invalids .. " MoveIsAttackWhenDistance"
		MoveIsAttackWhenDistance = 0
	else
		-- Verify the range
		if MoveIsAttackWhenDistance < 0 then
			MoveIsAttackWhenDistance = 0
		elseif MoveIsAttackWhenDistance > 5 then
			MoveIsAttackWhenDistance = 5
		end
	end
	
	-------------------------------
	-- Check if any were invalid --
	-------------------------------
	
	if invalids ~= "" then
		-- Output all the ones that were invalid
		Log(0,"Invalid configuration values for the following options:%s",tostring(invalids))
	end
	
	if oorange ~= "" then
		-- Output all the options that were out of range
		Log(0,"The following options had values that were out of range:%s",tostring(oorange))
	end
end
