--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

--------------------
-- Initialization --
--------------------

-- Function to initialize friend-recognition
function InitFriends()
	-- Attempt to load our friends
	LoadFriends()

	-- Check if our friends table exists
	if Friends == nil then
		-- Create a blank one
		Friends = { }
	end

	-- What about our friends?
	if not DefendFriends then
		-- Absolutely not
		IsFriend = FalseReturn
	end
end

---------------------
-- Friend Controls --
---------------------

-- Add a friend
function AddFriend(actor)
	-- Log it
	Log(0,"Adding Actor #%d to friend list.",actor)

	-- Add them
	Friends[actor] = true

	-- Check if we want to automatically save our friends
	if AutoSaveFriends then
		SaveFriends()
	end
end

-- Remove a friend
function DelFriend(actor)
	-- Log it
	Log(0,"Removing Actor #%d from friend list.",actor)

	-- Remove them
	Friends[actor] = false

	-- Check if we want to automatically save our friends
	if AutoSaveFriends then
		SaveFriends()
	end
end

---------------------------
-- Friend Identification --
---------------------------

-- Identify any friends
function IsFriend(actor)
	if IsPermFriend(actor) or IsTempFriend(actor) then
		return true
	end

	return false
end

-- Identify permanent friends
function IsPermFriend(actor)
	if Friends[actor] == true then
		return true
	end

	return false
end

-- Identify temporary friends
function IsTempFriend(actor)
	if TempFriends[actor] == true then
		return true
	end

	return false
end

---------------------------
-- Friend loading/saving --
---------------------------

-- Load the friends table
function LoadFriends()
	-- Generate the path/filename
	local filename = ScriptLocation .. "Conf/Friends.lua"

	-- Log it
	Log(0,"Loading friend-list from %q.",filename)

	-- Read the file as a lua function
	local func = loadfile(filename)

	-- Check if we have it
	if func ~= nil then
		-- Func is a valid function, so run it
		func()
	end
end

-- Save the friends table
function SaveFriends()
	-- Generate the data before saving it
	local out = ""

	-- Add the license notice
	out = "--[[\n" ..
		"\n" ..
		"This file is part of RampageAI.\n" ..
		"\n" ..
		"RampageAI is free software; you can redistribute it and/or modify\n" ..
		"it under the terms of the GNU General Public License as published by\n" ..
		"the Free Software Foundation; either version 2 of the License, or\n" ..
		"(at your option) any later version.\n" ..
		"\n" ..
		"RampageAI is distributed in the hope that it will be useful,\n" ..
		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n" ..
		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" ..
		"GNU General Public License for more details.\n" ..
		"\n" ..
		"You should have received a copy of the GNU General Public License\n" ..
		"along with RampageAI; if not, write to the Free Software\n" ..
		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA\n" ..
		"\n" ..
		"--]]\n" ..
		"\n" ..
		"\n"

	-- Add the beginning of the friends table object
	out = out .. "Friends = { }\n"

	-- Loop through each friend entry
	local actor,i
	for actor,i in Friends do
		-- Check if they're a friend
		if i then
			-- Add it to the output
			out = out .. string.format("Friends[%d] = true\n",actor)
		end
	end

	-- Generate the location of the file
	local filename = ScriptLocation .. "Conf/Friends.lua"

	-- Log it
	Log(0,"Saving friend-list to %q.",filename)

	-- Open the file for writing
	local savefile = io.open(filename, "w")

	-- Write the data
	savefile:write(out)

	-- Close the file
	savefile:close()
end
