--[[

This file is part of RampageAI.

RampageAI is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

RampageAI is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with RampageAI; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

--]]

--------------------
-- Timeout Object --
--------------------

Timeout = { }
Timeout.timeouts = { n=0 }

-- Add a new timeout
function Timeout.add(tEnd,func,repeatable)
	-- Get the current time
	local start = GetTick()

	-- Check our repeat value
	if repeatable == nil then
		repeatable = false
	end

	-- Setup a new item in our list
	Timeout.timeouts.n = Timeout.timeouts.n + 1
	Timeout.timeouts[Timeout.timeouts.n] =
		{ start, tEnd, func, repeatable }

	-- Return the place of it
	return Timeout.timeouts.n
end

-- Check all the timeouts
function Timeout.iterate()
	-- Get our current ticks
	local ticks = GetTick()

	-- Loop through all of our timeouts
	local i,timeout
	for i=1,Timeout.timeouts.n do
		-- Grab the timeout
		timeout = Timeout.timeouts[i]

		-- Make sure its not a nil timeout
		if timeout ~= nil then
			-- Check if its time to call the function
			if (timeout[1]+timeout[2]) <= ticks then
				-- Call the function, and pass it the amount of time
				-- that has passed
				local func = timeout[3]
				func(ticks - timeout[1])

				-- Check if we should repeat
				if timeout[4] then
					timeout[1] = ticks
				else
					-- Remove the timeout
					Timeout.timeouts[i] = nil
				end
			end
		end
	end
end